==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/mobilepacketcore/kotlin/NetworkFunctionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilepacketcore.kotlin

import com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs.builder
import com.pulumi.azurenative.mobilepacketcore.kotlin.enums.NetworkFunctionAdministrativeState
import com.pulumi.azurenative.mobilepacketcore.kotlin.enums.NetworkFunctionType
import com.pulumi.azurenative.mobilepacketcore.kotlin.enums.SkuDefinitions
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * AO5GC Network Function Resource
 * Azure REST API version: 2023-05-15-preview.
 * ## Example Usage
 * ### NetworkFunctions_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var networkFunction = new AzureNative.MobilePacketCore.NetworkFunction("networkFunction", new()
 *     {
 *         Capacity = 100000,
 *         DeploymentNotes = "string",
 *         Location = "eastus",
 *         NetworkFunctionAdministrativeState = "Commissioned",
 *         NetworkFunctionName = "nf1",
 *         NetworkFunctionType = "SMF",
 *         ResourceGroupName = "rg1",
 *         Sku = "NexusProduction",
 *         UserDescription = "string",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/mobilepacketcore/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := mobilepacketcore.NewNetworkFunction(ctx, "networkFunction", &mobilepacketcore.NetworkFunctionArgs{
 * 			Capacity:                           pulumi.Int(100000),
 * 			DeploymentNotes:                    pulumi.String("string"),
 * 			Location:                           pulumi.String("eastus"),
 * 			NetworkFunctionAdministrativeState: pulumi.String("Commissioned"),
 * 			NetworkFunctionName:                pulumi.String("nf1"),
 * 			NetworkFunctionType:                pulumi.String("SMF"),
 * 			ResourceGroupName:                  pulumi.String("rg1"),
 * 			Sku:                                pulumi.String("NexusProduction"),
 * 			UserDescription:                    pulumi.String("string"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.mobilepacketcore.NetworkFunction;
 * import com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var networkFunction = new NetworkFunction("networkFunction", NetworkFunctionArgs.builder()
 *             .capacity(100000)
 *             .deploymentNotes("string")
 *             .location("eastus")
 *             .networkFunctionAdministrativeState("Commissioned")
 *             .networkFunctionName("nf1")
 *             .networkFunctionType("SMF")
 *             .resourceGroupName("rg1")
 *             .sku("NexusProduction")
 *             .userDescription("string")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:mobilepacketcore:NetworkFunction nf1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MobilePacketCore/networkFunctions/{networkFunctionName}
 * ```
 * @property capacity Capacity of the network function in units of 10000.  This represents the session count or the Simultaneously Attached Users (SAU) count as applicable
 * @property deploymentNotes User provided deployment notes.  This is used to optionally provide details about the NF deployment
 * @property location The geo-location where the resource lives
 * @property networkFunctionAdministrativeState Administrative state of the network function
 * @property networkFunctionName The name of the network function
 * @property networkFunctionType Type of network function
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sku Provisioned SKU Value.
 * @property tags Resource tags.
 * @property userDescription User provided description
 */
public data class NetworkFunctionArgs(
    public val capacity: Output<Int>? = null,
    public val deploymentNotes: Output<String>? = null,
    public val location: Output<String>? = null,
    public val networkFunctionAdministrativeState:
    Output<Either<String, NetworkFunctionAdministrativeState>>? = null,
    public val networkFunctionName: Output<String>? = null,
    public val networkFunctionType: Output<Either<String, NetworkFunctionType>>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val sku: Output<Either<String, SkuDefinitions>>? = null,
    public val tags: Output<Map<String, String>>? = null,
    public val userDescription: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs =
        com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs.builder()
            .capacity(capacity?.applyValue({ args0 -> args0 }))
            .deploymentNotes(deploymentNotes?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .networkFunctionAdministrativeState(
                networkFunctionAdministrativeState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .networkFunctionName(networkFunctionName?.applyValue({ args0 -> args0 }))
            .networkFunctionType(
                networkFunctionType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .sku(
                sku?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tags(tags?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .userDescription(userDescription?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkFunctionArgs].
 */
@PulumiTagMarker
public class NetworkFunctionArgsBuilder internal constructor() {
    private var capacity: Output<Int>? = null

    private var deploymentNotes: Output<String>? = null

    private var location: Output<String>? = null

    private var networkFunctionAdministrativeState:
        Output<Either<String, NetworkFunctionAdministrativeState>>? = null

    private var networkFunctionName: Output<String>? = null

    private var networkFunctionType: Output<Either<String, NetworkFunctionType>>? = null

    private var resourceGroupName: Output<String>? = null

    private var sku: Output<Either<String, SkuDefinitions>>? = null

    private var tags: Output<Map<String, String>>? = null

    private var userDescription: Output<String>? = null

    /**
     * @param value Capacity of the network function in units of 10000.  This represents the session count or the Simultaneously Attached Users (SAU) count as applicable
     */
    @JvmName("mtfamqbxqkirogya")
    public suspend fun capacity(`value`: Output<Int>) {
        this.capacity = value
    }

    /**
     * @param value User provided deployment notes.  This is used to optionally provide details about the NF deployment
     */
    @JvmName("ltrixtymsfkhbwdc")
    public suspend fun deploymentNotes(`value`: Output<String>) {
        this.deploymentNotes = value
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("phwmhnxcxtaqgfan")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("wseehoatumehenib")
    public suspend
    fun networkFunctionAdministrativeState(`value`: Output<Either<String, NetworkFunctionAdministrativeState>>) {
        this.networkFunctionAdministrativeState = value
    }

    /**
     * @param value The name of the network function
     */
    @JvmName("jvdjgewkrxhfcpqk")
    public suspend fun networkFunctionName(`value`: Output<String>) {
        this.networkFunctionName = value
    }

    /**
     * @param value Type of network function
     */
    @JvmName("faumtrvnoqcoknpl")
    public suspend fun networkFunctionType(`value`: Output<Either<String, NetworkFunctionType>>) {
        this.networkFunctionType = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("klaoxvdeewdvkpyi")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("gannjjteksllocgx")
    public suspend fun sku(`value`: Output<Either<String, SkuDefinitions>>) {
        this.sku = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("kflqoiqussugtdra")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value User provided description
     */
    @JvmName("yypnspdttyofakvj")
    public suspend fun userDescription(`value`: Output<String>) {
        this.userDescription = value
    }

    /**
     * @param value Capacity of the network function in units of 10000.  This represents the session count or the Simultaneously Attached Users (SAU) count as applicable
     */
    @JvmName("paqnswfixayqbqkp")
    public suspend fun capacity(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param value User provided deployment notes.  This is used to optionally provide details about the NF deployment
     */
    @JvmName("hitylndeggpotaxx")
    public suspend fun deploymentNotes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentNotes = mapped
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("tvmkkyoaospcnbbs")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("edysxnbbfcmqdaqn")
    public suspend
    fun networkFunctionAdministrativeState(`value`: Either<String, NetworkFunctionAdministrativeState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkFunctionAdministrativeState = mapped
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("drpkvvmyohbytewt")
    public fun networkFunctionAdministrativeState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkFunctionAdministrativeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionAdministrativeState = mapped
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("dmowfjxepbcxcotr")
    public fun networkFunctionAdministrativeState(`value`: NetworkFunctionAdministrativeState) {
        val toBeMapped = Either.ofRight<String, NetworkFunctionAdministrativeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionAdministrativeState = mapped
    }

    /**
     * @param value The name of the network function
     */
    @JvmName("fbgvnphgeuxqypde")
    public suspend fun networkFunctionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkFunctionName = mapped
    }

    /**
     * @param value Type of network function
     */
    @JvmName("chsgfqspfckibjif")
    public suspend fun networkFunctionType(`value`: Either<String, NetworkFunctionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkFunctionType = mapped
    }

    /**
     * @param value Type of network function
     */
    @JvmName("rfcqmcbultltvmbf")
    public fun networkFunctionType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkFunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionType = mapped
    }

    /**
     * @param value Type of network function
     */
    @JvmName("gmcnnjfbdkwbvord")
    public fun networkFunctionType(`value`: NetworkFunctionType) {
        val toBeMapped = Either.ofRight<String, NetworkFunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionType = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("dktmyyqohjqthopv")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("paqrodmqyvhxsxhc")
    public suspend fun sku(`value`: Either<String, SkuDefinitions>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("dgqrcmldhvkdnmnt")
    public fun sku(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuDefinitions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("orbyyxjqojuascuy")
    public fun sku(`value`: SkuDefinitions) {
        val toBeMapped = Either.ofRight<String, SkuDefinitions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("mhmgxapiorxyrvxu")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("qtcxlbapealbboxd")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value User provided description
     */
    @JvmName("pclvxysdxioliyso")
    public suspend fun userDescription(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userDescription = mapped
    }

    internal fun build(): NetworkFunctionArgs = NetworkFunctionArgs(
        capacity = capacity,
        deploymentNotes = deploymentNotes,
        location = location,
        networkFunctionAdministrativeState = networkFunctionAdministrativeState,
        networkFunctionName = networkFunctionName,
        networkFunctionType = networkFunctionType,
        resourceGroupName = resourceGroupName,
        sku = sku,
        tags = tags,
        userDescription = userDescription,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/mobilepacketcore/kotlin/NetworkFunctionArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.mobilepacketcore.kotlin

import com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs.builder
import com.pulumi.azurenative.mobilepacketcore.kotlin.enums.NetworkFunctionAdministrativeState
import com.pulumi.azurenative.mobilepacketcore.kotlin.enums.NetworkFunctionType
import com.pulumi.azurenative.mobilepacketcore.kotlin.enums.SkuDefinitions
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.Int
import kotlin.Pair
import kotlin.String
import kotlin.Suppress
import kotlin.collections.Map
import kotlin.jvm.JvmName

/**
 * AO5GC Network Function Resource
 * Azure REST API version: 2023-05-15-preview.
 * ## Example Usage
 * ### NetworkFunctions_CreateOrUpdate
 * ```csharp
 * using System.Collections.Generic;
 * using System.Linq;
 * using Pulumi;
 * using AzureNative = Pulumi.AzureNative;
 * return await Deployment.RunAsync(() =>
 * {
 *     var networkFunction = new AzureNative.MobilePacketCore.NetworkFunction("networkFunction", new()
 *     {
 *         Capacity = 100000,
 *         DeploymentNotes = "string",
 *         Location = "eastus",
 *         NetworkFunctionAdministrativeState = "Commissioned",
 *         NetworkFunctionName = "nf1",
 *         NetworkFunctionType = "SMF",
 *         ResourceGroupName = "rg1",
 *         Sku = "NexusProduction",
 *         UserDescription = "string",
 *     });
 * });
 * ```
 * ```go
 * package main
 * import (
 * 	"github.com/pulumi/pulumi-azure-native-sdk/mobilepacketcore/v2"
 * 	"github.com/pulumi/pulumi/sdk/v3/go/pulumi"
 * )
 * func main() {
 * 	pulumi.Run(func(ctx *pulumi.Context) error {
 * 		_, err := mobilepacketcore.NewNetworkFunction(ctx, "networkFunction", &mobilepacketcore.NetworkFunctionArgs{
 * 			Capacity:                           pulumi.Int(100000),
 * 			DeploymentNotes:                    pulumi.String("string"),
 * 			Location:                           pulumi.String("eastus"),
 * 			NetworkFunctionAdministrativeState: pulumi.String("Commissioned"),
 * 			NetworkFunctionName:                pulumi.String("nf1"),
 * 			NetworkFunctionType:                pulumi.String("SMF"),
 * 			ResourceGroupName:                  pulumi.String("rg1"),
 * 			Sku:                                pulumi.String("NexusProduction"),
 * 			UserDescription:                    pulumi.String("string"),
 * 		})
 * 		if err != nil {
 * 			return err
 * 		}
 * 		return nil
 * 	})
 * }
 * ```
 * ```java
 * package generated_program;
 * import com.pulumi.Context;
 * import com.pulumi.Pulumi;
 * import com.pulumi.core.Output;
 * import com.pulumi.azurenative.mobilepacketcore.NetworkFunction;
 * import com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs;
 * import java.util.List;
 * import java.util.ArrayList;
 * import java.util.Map;
 * import java.io.File;
 * import java.nio.file.Files;
 * import java.nio.file.Paths;
 * public class App {
 *     public static void main(String[] args) {
 *         Pulumi.run(App::stack);
 *     }
 *     public static void stack(Context ctx) {
 *         var networkFunction = new NetworkFunction("networkFunction", NetworkFunctionArgs.builder()
 *             .capacity(100000)
 *             .deploymentNotes("string")
 *             .location("eastus")
 *             .networkFunctionAdministrativeState("Commissioned")
 *             .networkFunctionName("nf1")
 *             .networkFunctionType("SMF")
 *             .resourceGroupName("rg1")
 *             .sku("NexusProduction")
 *             .userDescription("string")
 *             .build());
 *     }
 * }
 * ```
 * ## Import
 * An existing resource can be imported using its type token, name, and identifier, e.g.
 * ```sh
 * $ pulumi import azure-native:mobilepacketcore:NetworkFunction nf1 /subscriptions/{subscriptionId}/resourceGroups/{resourceGroupName}/providers/Microsoft.MobilePacketCore/networkFunctions/{networkFunctionName}
 * ```
 * @property capacity Capacity of the network function in units of 10000.  This represents the session count or the Simultaneously Attached Users (SAU) count as applicable
 * @property deploymentNotes User provided deployment notes.  This is used to optionally provide details about the NF deployment
 * @property location The geo-location where the resource lives
 * @property networkFunctionAdministrativeState Administrative state of the network function
 * @property networkFunctionName The name of the network function
 * @property networkFunctionType Type of network function
 * @property resourceGroupName The name of the resource group. The name is case insensitive.
 * @property sku Provisioned SKU Value.
 * @property tags Resource tags.
 * @property userDescription User provided description
 */
public data class NetworkFunctionArgs(
    public val capacity: Output<Int>? = null,
    public val deploymentNotes: Output<String>? = null,
    public val location: Output<String>? = null,
    public val networkFunctionAdministrativeState:
    Output<Either<String, NetworkFunctionAdministrativeState>>? = null,
    public val networkFunctionName: Output<String>? = null,
    public val networkFunctionType: Output<Either<String, NetworkFunctionType>>? = null,
    public val resourceGroupName: Output<String>? = null,
    public val sku: Output<Either<String, SkuDefinitions>>? = null,
    public val tags: Output<Map<String, String>>? = null,
    public val userDescription: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs> {
    override fun toJava(): com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs =
        com.pulumi.azurenative.mobilepacketcore.NetworkFunctionArgs.builder()
            .capacity(capacity?.applyValue({ args0 -> args0 }))
            .deploymentNotes(deploymentNotes?.applyValue({ args0 -> args0 }))
            .location(location?.applyValue({ args0 -> args0 }))
            .networkFunctionAdministrativeState(
                networkFunctionAdministrativeState?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            )
            .networkFunctionName(networkFunctionName?.applyValue({ args0 -> args0 }))
            .networkFunctionType(
                networkFunctionType?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .resourceGroupName(resourceGroupName?.applyValue({ args0 -> args0 }))
            .sku(
                sku?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .tags(tags?.applyValue({ args0 -> args0.map({ args0 -> args0.key.to(args0.value) }).toMap() }))
            .userDescription(userDescription?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [NetworkFunctionArgs].
 */
@PulumiTagMarker
public class NetworkFunctionArgsBuilder internal constructor() {
    private var capacity: Output<Int>? = null

    private var deploymentNotes: Output<String>? = null

    private var location: Output<String>? = null

    private var networkFunctionAdministrativeState:
        Output<Either<String, NetworkFunctionAdministrativeState>>? = null

    private var networkFunctionName: Output<String>? = null

    private var networkFunctionType: Output<Either<String, NetworkFunctionType>>? = null

    private var resourceGroupName: Output<String>? = null

    private var sku: Output<Either<String, SkuDefinitions>>? = null

    private var tags: Output<Map<String, String>>? = null

    private var userDescription: Output<String>? = null

    /**
     * @param value Capacity of the network function in units of 10000.  This represents the session count or the Simultaneously Attached Users (SAU) count as applicable
     */
    @JvmName("lvjgjaeeejeodbis")
    public suspend fun capacity(`value`: Output<Int>) {
        this.capacity = value
    }

    /**
     * @param value User provided deployment notes.  This is used to optionally provide details about the NF deployment
     */
    @JvmName("aglnjudrwnjknwpl")
    public suspend fun deploymentNotes(`value`: Output<String>) {
        this.deploymentNotes = value
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("gdfdxfmuyvblpmqc")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("jwcycukpveaoipmb")
    public suspend
    fun networkFunctionAdministrativeState(`value`: Output<Either<String, NetworkFunctionAdministrativeState>>) {
        this.networkFunctionAdministrativeState = value
    }

    /**
     * @param value The name of the network function
     */
    @JvmName("xofukqdpmlaarqnw")
    public suspend fun networkFunctionName(`value`: Output<String>) {
        this.networkFunctionName = value
    }

    /**
     * @param value Type of network function
     */
    @JvmName("lorpwdierpeuuoig")
    public suspend fun networkFunctionType(`value`: Output<Either<String, NetworkFunctionType>>) {
        this.networkFunctionType = value
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("bvsdimrhkuiparqn")
    public suspend fun resourceGroupName(`value`: Output<String>) {
        this.resourceGroupName = value
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("swnjpjchekqeomoc")
    public suspend fun sku(`value`: Output<Either<String, SkuDefinitions>>) {
        this.sku = value
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("nhwsckegopakimmi")
    public suspend fun tags(`value`: Output<Map<String, String>>) {
        this.tags = value
    }

    /**
     * @param value User provided description
     */
    @JvmName("yilgjbenfyntydrm")
    public suspend fun userDescription(`value`: Output<String>) {
        this.userDescription = value
    }

    /**
     * @param value Capacity of the network function in units of 10000.  This represents the session count or the Simultaneously Attached Users (SAU) count as applicable
     */
    @JvmName("nmpnidntknnxbksr")
    public suspend fun capacity(`value`: Int?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.capacity = mapped
    }

    /**
     * @param value User provided deployment notes.  This is used to optionally provide details about the NF deployment
     */
    @JvmName("tqvcoxkldbaborof")
    public suspend fun deploymentNotes(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.deploymentNotes = mapped
    }

    /**
     * @param value The geo-location where the resource lives
     */
    @JvmName("okayoqfvmsdentgr")
    public suspend fun location(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("xlaqivqxhkidcxnm")
    public suspend
    fun networkFunctionAdministrativeState(`value`: Either<String, NetworkFunctionAdministrativeState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkFunctionAdministrativeState = mapped
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("ystygweilyhhqoey")
    public fun networkFunctionAdministrativeState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkFunctionAdministrativeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionAdministrativeState = mapped
    }

    /**
     * @param value Administrative state of the network function
     */
    @JvmName("jumtypsrjmrvjluw")
    public fun networkFunctionAdministrativeState(`value`: NetworkFunctionAdministrativeState) {
        val toBeMapped = Either.ofRight<String, NetworkFunctionAdministrativeState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionAdministrativeState = mapped
    }

    /**
     * @param value The name of the network function
     */
    @JvmName("pmuwymeiesbogpkl")
    public suspend fun networkFunctionName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkFunctionName = mapped
    }

    /**
     * @param value Type of network function
     */
    @JvmName("thtjxunljrjijhte")
    public suspend fun networkFunctionType(`value`: Either<String, NetworkFunctionType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkFunctionType = mapped
    }

    /**
     * @param value Type of network function
     */
    @JvmName("wseijqenyvtxhhrk")
    public fun networkFunctionType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NetworkFunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionType = mapped
    }

    /**
     * @param value Type of network function
     */
    @JvmName("ijcninuhbsmtgffb")
    public fun networkFunctionType(`value`: NetworkFunctionType) {
        val toBeMapped = Either.ofRight<String, NetworkFunctionType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.networkFunctionType = mapped
    }

    /**
     * @param value The name of the resource group. The name is case insensitive.
     */
    @JvmName("bibpjmxqawhdhsum")
    public suspend fun resourceGroupName(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.resourceGroupName = mapped
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("fgxffcwoeuigdapu")
    public suspend fun sku(`value`: Either<String, SkuDefinitions>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("orfhssjgbyilyirh")
    public fun sku(`value`: String) {
        val toBeMapped = Either.ofLeft<String, SkuDefinitions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value Provisioned SKU Value.
     */
    @JvmName("stlrpnjnlptkyryl")
    public fun sku(`value`: SkuDefinitions) {
        val toBeMapped = Either.ofRight<String, SkuDefinitions>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.sku = mapped
    }

    /**
     * @param value Resource tags.
     */
    @JvmName("pypfsvpfkjbnweme")
    public suspend fun tags(`value`: Map<String, String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param values Resource tags.
     */
    @JvmName("hcpqjvqvaejcpxsx")
    public fun tags(vararg values: Pair<String, String>) {
        val toBeMapped = values.toMap()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.tags = mapped
    }

    /**
     * @param value User provided description
     */
    @JvmName("qgerbtimypccbwiy")
    public suspend fun userDescription(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.userDescription = mapped
    }

    internal fun build(): NetworkFunctionArgs = NetworkFunctionArgs(
        capacity = capacity,
        deploymentNotes = deploymentNotes,
        location = location,
        networkFunctionAdministrativeState = networkFunctionAdministrativeState,
        networkFunctionName = networkFunctionName,
        networkFunctionType = networkFunctionType,
        resourceGroupName = resourceGroupName,
        sku = sku,
        tags = tags,
        userDescription = userDescription,
    )
}
